@@ -1,4 +1,4 @@
-suppressWarnings(library(dplyr))
+library(dplyr, warn.conflicts = FALSE)
 
 dat <- tribble(
   ~a1, ~a2, ~a3, ~a4, ~a5, ~a6, ~a7, ~a8, ~a9, ~a10,
